@@ -103,11 +103,13 @@ def validate_lims(
 def validations(
     db_address: str,
     lims_id: str,
+    asset_type: Optional[str] = typer.Argument(None),
 ) -> None:
     client = MongoClient(db_address)
     validations = get_validation_results(
         client,
         lims_id,
+        asset_type,
         "dev",
     )
     if not len(validations) > 0:
@@ -116,7 +118,10 @@ def validations(
 
     console.print("Found validations:")
     for validation in validations:
-        console.print(from_AssetValidationResult(validation))
+        console.print("Asset type: %s" % validation.manifest.asset_type)
+        validation_dict = from_AssetValidationResult(validation)
+        validation_dict.pop(manifest)  # don't display, manifest...TODO do this better?
+        console.print(validation_dict)
 
 
 if __name__ == "__main__":
